A simple standalone Docker image for DMX - The Context Machine
==============================================================

* Get the repo:

    `git clone https://git.dmx.systems/dmx-contrib/dmx-docker.git`


* Run:

    Run `./dmx-docker.sh` (Uses the pre-built image from our [DMX container registry](https://git.dmx.systems/dmx-contrib/dmx-docker/container_registry).) 


* Alternatively run `docker-compose -d up` (adjust docker-compose.yml and .env files to your needs).


* Build local image (optional):

```
    docker build \
        --build-arg dmx_version="5.2.1" \
        --build-arg dmx_download_url="download.dmx.systems" \
        --no-cache --tag dmx-5.2.1 .
```



Notes
-----

You can customize the default DMX config by inserting config snippets
to the conf.d/config.properties.d and conf.d/logging.properties.d directories.
(=> see bootstrap/10_logging_properties_example).

To install plugin jars via bootstrap, place them in the plugins directory.

Differences between original download and container version:

* removed all 3 bundle/org.apache.felix.gogo.*.jar files
* dmx.security.subnet_filter = 0.0.0.0/0
* dmx.filerepo.path = /opt/dmx/dmx-filedir
* logging.properties are configured to use the file handler with log rotation (=> logs/dmx0.log..dmx9.log)


Our docker images are also available on [Docker Hub](https://hub.docker.com/u/dmxsystems).


How it all works together
-------------------------

The aim of this DMX Docker Image is to provide a lightweight docker container to just
run a DMX instance out of the box, but also to allow for manual and scripted configuration.

The easiest way to start the container is using the `./dmx-docker.sh` script. It will automatically
create the exported folders for all docker volumes underneath the working directory's dmx-docker directory.

```
dmx-docker
├── bundle-available             # <= extra folder for available plugin jars
├── bundle-deploy                # <= default DMX folder to add and activate plugin jars
├── conf                         # <= default DMX folder for configuration files
├── conf.d                       # <= extra folder for scripted configuration
├── conf.d/config.properties.d   # <= extra folder for scripted configuration
├── conf.d/logging.properties.d  # <= extra folder for scripted configuration
├── dmx-db                       # <= default DMX folder for the database
├── dmx-filedir                  # <= extra folder for file repository
├── logs                         # <= extra folder for log files
├── plugins                      # <= extra folder for scripted deployment of plugin jars
├── modules                      # <= extra folder for scripted deployment of module jars
├── run.d                        # <= extra folder for command execution
└── import                       # <= extra folder for scripted data import
```

The DMX instance will be available by entering http://localhost:8080/systems.dmx.webclient/ into your web browser.
Login with user name `admin` and no password. Set the password after your first login.

Check our documentation at https://docs.dmx.systems for further instructions.
Visit our forum at https://forum.dmx.systems for questions or feedback.


Configuration
-------------

The container offers two different layers of configuration changes:

1. Direct manipulation of conf/config.properties and conf/logging.properties files.
   You must not opt for point 2. here then, as it will overwrite the config files.

2. Putting your configuration changes in file snippets underneath the `conf.d/config.properties.d` and the `conf.d/logging.properties.d` folders.
   The snippets will be scanned for changes on each container start and the changes will be written to the default config files in the `conf` folder.   
   See bootstrap/10_logging_properties_example for a configuration example via file snippet.

For plugins that require or allow for additional external configuration resources (like language specific or design related files) you can create a related `conf.d/dmx-plugin-name` folder, since any directory in `conf.d` will be copied to the `conf` folder.


Plugins
-------

The container allows for three different ways of plugin deployment:

1. Putting the plugins directly to the `bundle-deploy` folder. Plugin jars will be deployed right away and without restarting the container.

2. Putting the plugins to the extra `bundle-available` folder and activate or deactivate them via dmxenplug or dmxdisplug script. No restart required.

3. Putting the plugins to the extra `plugins` folder. Plugin jars will be copied to the `bundle-deploy` folder while bootstrapping. Existing plugins in the `bundle-deploy` folder will be updated with newer versions on each container start. 

Check our website at https://dmx.berlin/plugins/ for available DMX plugins and further information.


Modules
-------

The container allows for two different ways to add new or overwrite existing platform modules:

1. Putting the module jars to the extra `modules` folder. Module jars will be copied to the `bundle` folder while bootstrapping. Existing plugins in the `bundle` folder will be updated with any changed versions on each container start. 

2. Mounting the modules folder directly to the container's `bundle` folder. In this case the folder must container all required modules.

NOTE: This feature is usually only relevant for testing new platform modules during development.


Import
------

The container can import a pre-filled database or a set of files from tarballs on bootstrap. This might be especially relevant for software testing or certain deployment scenarios.

1. Create tarball(s): `tar czf dmx-db.tar.gz dmx-db/` and/or `tar czf dmx-filedir.tar.gz dmx-filedir/`.

2. Put the file(s) in the `import` folder and (re-)start the container.

IMPORTANT NOTE: If tarballs are found in the import folder, all existing data and files will be replaced with the newly imported ones.


Scripts
-------

The container lets you run additional commands on bootstrap via placing busybox shell script snippets in the `run.d` folder. Each line of each file is executed via `/bin/sh -c "${line}"`. Example:

1. Create a text file `10_ls_opt_dmx` containing `ls -la /opt/dmx` in the `run.d` folder. (The file must end with an empty line!)

2. Check the logfile `./logs/bootstrap.log` for results.


License
-------

Written by Juergen Neumann <juergen@dmx.systems>    
Copyright (C) 2021-2024 DMX Systems <https://dmx.systems>    
DMX is available freely under the GNU Affero General Public License, version 3.    
